body{margin:0;overflow:hidden;background-color:#050a18;font-family:Space Mono,monospace}canvas{position:fixed;top:0;left:0}#header{position:fixed;top:0;left:0;right:0;padding:20px 32px;display:flex;align-items:center;gap:12px;z-index:20;pointer-events:none}#header-text{font-size:20px;color:#e8eaf6;letter-spacing:.05em}#controls{margin-left:auto;display:flex;align-items:center;gap:8px;pointer-events:all}.button{background:transparent;border:1px solid rgba(255,255,255,.15);border-radius:6px;color:#ffffff38;font-size:11px;padding:5px 14px;cursor:pointer;letter-spacing:.08em;transition:all .2s}.button.active{background:#ffffff1f;border:1px solid rgba(255,255,255,.35);color:#e8eaf6,}.zoom-button{width:32px;padding:5px 0;text-align:center}#header-hint{font-size:11px;color:#ffffff38}#legend{position:fixed;bottom:24px;left:32px;display:flex;flex-direction:column;gap:7px;z-index:20;pointer-events:none}.legend-row{display:flex;align-items:center;gap:8px}.legend-icon{width:9px;height:9px;border-radius:50%;flex-shrink:0}#sun-icon{box-shadow:0 0 6px #ffb300}.legend-label{font-size:10px;color:#ffffff47}#size-note{font-size:10px;color:#ffffff47;margin-top:6px;border-top:1px solid rgba(255,255,255,.07);padding-top:6px;line-height:1.6}#tooltip{position:fixed;display:none;background:#080c26f5;border:1px solid rgba(255,255,255,.1);border-radius:8px;padding:10px 14px;pointer-events:none;z-index:100;-webkit-backdrop-filter:blur(8px);backdrop-filter:blur(8px);min-width:170px}.tooltip-primary{font-size:13px;font-weight:700;color:#e8eaf6}.tooltip-secondary{font-size:11px;color:#fff6;margin-top:2px;margin-bottom:3px}.tooltip-tertary{font-size:10px;color:#ffffff47;margin-top:2px}#tooltip-badge{display:inline-block;margin-top:6px;padding:2px 7px;border-radius:4px;font-size:9px;font-weight:700;color:#050a18}#extra-info{position:fixed;bottom:24px;right:32px;font-size:10px;color:#ffffff47;z-index:20;pointer-events:none;line-height:1.7;text-align:right}
